@@ -162,8 +162,9 @@ class LambdaHandler:
         print("[ERROR] AWS_EVENT", dir(self.aws_event))
         print("[ERROR] AWS_EVENT", self.aws_event)
 
-        aws_event = to_json(self.aws_event)
-        context.response.set_body({"event": aws_event, "postdata": context.postdata()})
+        context.response().set_body(
+            {"event": self.aws_event, "postdata": context.postdata()}
+        )
 
     def OnActionTracking(self, tx, context):
         self.track(tx, context.payload().get("data", {}))
